import 'package:bolter_flutter/bolter_flutter.dart';
import 'package:hive/hive.dart';

mixin Restorable<T> on Presenter {
  Box<T> _box;

  String get key;

  void Function() get registerAdapters;

  Future<T> getStored() async {
    try {
      registerAdapters();
      _box = await Hive.openBox(key);
      return _box.get('auth');
    } catch (e) {
      Hive.deleteBoxFromDisk('auth');
      _box = await Hive.openBox(key);
      return null;
    }
  }

  Future<void> close() async {
    await _box?.close();
  }

  void save(T value) {
    _box?.put(key, value);
  }
}
